function loadsisec(room,set,k,fs)
% LOADSISEC(room,set,k,fs)
% Load data from the database of recordings of two simultaneously playing
% sources (SiSEC 2010 evaluation campaign, the "Robust blind linear/non-linear 
% separation of short two-sources-two-microphones %recordings" task, 
% http://sisec.wiki.irisa.fr/tiki-index.php)
%
% room ... the number of room
%          1 .. room1 - an ordinary living room
%          2 .. room2 - a study room with a PC
% set  ... the positions of loudspeakers - sources (see illustration)
% k ... the combination of signals (male x male speech, female x female, 
%       male x sneeze, male x laught, female x glass break, female x TV noise)
% fs ... sampling frequency (default is 16 kHz)
%
% Shoko Araki, Alexey Ozerov, Vikrham Gowreesunker, Hiroshi Sawada, 
% Fabian Theis, Guido Nolte, Dominik Lutter, and Ngoc Q.K. Duong , 
% "The 2010 Signal Separation Evaluation Campaign (SiSEC2010): Audio Source 
% Separation," in Latent Variable Analysis and Signal Separation, Lecture 
% Notes in Computer Science Vol. 6365, pp. 114-122, ISBN: 978-3-642-15994-7, 
% Springer, Heidelberg, Sept. 2010.


if nargin<4
    fs=16000;
end

baseaddr='sisec2010/';

switch room
    case 1 
        file='room1';
    case 2 
        file='room2';
end
file=[baseaddr file '/' num2str(set) '/'];

im=dir([file '*.gif']);
imshow(imread([file im(1).name]));

combinations=[1 3; 2 4; 1 7; 1 5; 2 6; 2 8];


resp1=zeros(2,3*44100);
resp2=zeros(2,3*44100);
r=combinations(k,:);
resp1(1,:)=wavread([file 'mic1.wav'],[(r(1)-1)*3*44100+1 r(1)*3*44100])';
resp1(2,:)=wavread([file 'mic2.wav'],[(r(1)-1)*3*44100+1 r(1)*3*44100])';
resp2(1,:)=wavread([file 'mic1.wav'],[(r(2)-1)*3*44100+1 r(2)*3*44100])';
resp2(2,:)=wavread([file 'mic2.wav'],[(r(2)-1)*3*44100+1 r(2)*3*44100])';
x=resp1+resp2;
if fs~=44100
    x=resample(x',fs,44100)';
    resp1=resample(resp1',fs,44100)';
    resp2=resample(resp2',fs,44100)';
end    
%assignin('base',['x' num2str(k)],x(:,1:1*fs))
assignin('base','x',x)
resp=resp1;
resp(:,:,2)=resp2;
%assignin('base',['resp' num2str(k)],resp(:,1:1*fs,:))
assignin('base','resp',resp)
if k==1 % estimating SNR
    x=zeros(2,3*44100);
    x(1,:)=wavread([file 'mic1.wav'],[8*3*44100+1 9*3*44100])';
    x(2,:)=wavread([file 'mic2.wav'],[8*3*44100+1 9*3*44100])';
    if fs~=44100
        x=resample(x',fs,44100)';
    end
    noise=x-resp1-resp2;
    sigma2=mean(noise.^2,2)/3;
    fprintf('SNR of x1: L %.2f dB, R %.2f dB\n',...
        10*log10((mean(x(1,:).^2)-sigma2(1))/sigma2(1)),...
        10*log10((mean(x(2,:).^2)-sigma2(2))/sigma2(2)));
    fprintf('SNR of target source in x1: L %.2f dB, R %.2f dB\n',...
        10*log10((mean(resp1(1,:).^2)-sigma2(1))/sigma2(1)),...
        10*log10((mean(resp1(2,:).^2)-sigma2(2))/sigma2(2)));
    fprintf('SNR of jammer source in x1: L %.2f dB, R %.2f dB\n',...
        10*log10((mean(resp2(1,:).^2)-sigma2(1))/sigma2(1)),...
        10*log10((mean(resp2(2,:).^2)-sigma2(2))/sigma2(2)));
end






